Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(51)

Unified Diff: components/sync/driver/sync_client.h

Issue 2458013002: [Sync] Rename ModelTypeService to ModelTypeSyncBridge. (Closed)
Patch Set: s/SetBridgeError/ErrorOnNextCall Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/driver/sync_client.h
diff --git a/components/sync/driver/sync_client.h b/components/sync/driver/sync_client.h
index 2b8f35facb7ee508dec02dd5dafa6128127c24dc..f819bc23584ec2ed5d7fafbd3e0af024d89fef76 100644
--- a/components/sync/driver/sync_client.h
+++ b/components/sync/driver/sync_client.h
@@ -13,7 +13,7 @@
#include "components/sync/base/model_type.h"
#include "components/sync/driver/sync_api_component_factory.h"
#include "components/sync/engine/model_safe_worker.h"
-#include "components/sync/model/model_type_service.h"
+#include "components/sync/model/model_type_sync_bridge.h"
class BookmarkUndoService;
class PrefService;
@@ -94,10 +94,10 @@ class SyncClient {
virtual base::WeakPtr<SyncableService> GetSyncableServiceForType(
ModelType type) = 0;
// Returns a weak pointer to the ModelTypeService specified by |type|. Weak
// pointer may be unset if service is already destroyed.
// Note: Should only be dereferenced from the model type thread.
- virtual base::WeakPtr<ModelTypeService> GetModelTypeServiceForType(
+ virtual base::WeakPtr<ModelTypeSyncBridge> GetSyncBridgeForModelType(
ModelType type) = 0;
// Creates and returns a new ModelSafeWorker for the group, or null if one
« no previous file with comments | « components/sync/driver/model_type_controller_unittest.cc ('k') | components/sync/driver/sync_driver_switches.cc » ('j') | no next file with comments »
@@ -94,10 +94,10 @@ class SyncClient {
virtual base::WeakPtr<SyncableService> GetSyncableServiceForType(
ModelType type) = 0;
- // Returns a weak pointer to the ModelTypeService specified by |type|. Weak
+ // Returns a weak pointer to the ModelTypeSyncBridge specified by |type|. Weak
// pointer may be unset if service is already destroyed.
// Note: Should only be dereferenced from the model type thread.

Powered by Google App Engine
This is Rietveld 408576698